import hashlib

def encrypt_md5(txt):
    md5 = hashlib.md5()
    md5.update(bytes(txt, encoding='utf-8'))
    return md5.hexdigest()

def encrypt_sha256(txt):
    SHA = hashlib.sha256()
    SHA.update(txt.encode('utf-8'))
    return SHA.hexdigest()


import os
import logging
from logging.handlers import RotatingFileHandler
class InfoFilter(logging.Filter):
    def filter(self, record):
        """only use INFO
        筛选, 只需要 INFO 级别的log
        :param record:
        :return:
        """
        if logging.INFO <= record.levelno < logging.ERROR:
            # 已经是INFO级别了
            # 然后利用父类, 返回 1
            return super().filter(record)
        else:
            return 0

class AiosLogger():

    def __init__(self, log_path='logs'):
        # Formatter
        self.formatter = logging.Formatter(
            '%(asctime)s %(levelname)s %(process)d %(thread)d '
            '%(pathname)s %(lineno)s %(message)s')
        self.log_path = log_path
        if not os.path.exists(self.log_path):
            os.makedirs(self.log_path, mode=777)

    def get_info_handler(self):
        # FileHandler Info
        info_handler = RotatingFileHandler(filename=os.path.join(self.log_path, 'info.txt'))
        info_handler.setFormatter(self.formatter)
        info_handler.setLevel(logging.INFO)
        info_filter = InfoFilter()
        info_handler.addFilter(info_filter)
        return info_handler
        
    def get_error_handler(self):
        # FileHandler Error
        error_handler = RotatingFileHandler(filename=os.path.join(self.log_path, 'error.txt'))
        error_handler.setFormatter(self.formatter)
        error_handler.setLevel(logging.ERROR)
        return error_handler


from flask import request
from base_aios.utils.md5 import encrypt_sha256
from base_aios.utils.exceptions import UnauthorizedException

def verify_mutex_login(aios_redis, user_id, **kwargs):
    '''互斥登录校验，以异常的形式抛出
    '''
    assert user_id is not None, 'user_id is not none!'

    kwargs = kwargs or {}
    ACTIVE_KEY = kwargs.get('ACTIVE_KEY', 'bam:active:{}')
    MUTEX_LOGIN = kwargs.get('MUTEX_LOGIN', '您的账号在另一地点登录, 您已被迫下线!')

    current_access_token = request.headers.get('Authorization')
    # 本次请求的加密token
    actual_access_token = encrypt_sha256(current_access_token.lstrip('Bearer '))
    # 缓存中期望的加密token
    except_access_token = aios_redis.get(ACTIVE_KEY.format(user_id))
    if except_access_token is None:
        # 缓存失效时更新缓存
        aios_redis.set(ACTIVE_KEY.format(user_id), actual_access_token)
        except_access_token = actual_access_token

    if except_access_token != actual_access_token:
        raise UnauthorizedException(MUTEX_LOGIN)


import os
from configobj import ConfigObj

class Language(object):

    def __init__(self, accept_languages=[]):
        self._resource = dict()
        self.accept_languages = accept_languages

        ini_dir = os.path.join(os.getcwd(), 'base_aios', 'validate', 'languages')
        for root, dirs, files in os.walk(ini_dir):
            for file in filter(lambda x: x.endswith('.ini'), files):
                ini_file = os.path.join(root, file)
                config = ConfigObj(infile=ini_file)
                
                region = file.replace('.ini', '')
                
                lang_resources = dict()
                for section in config.sections:
                    if lang_resources.get(section) is None:
                        lang_resources.setdefault(section, dict())
                    for k in config[section]:
                        lang_resources[section][k] = config[section][k]
                
                self._resource[region] = lang_resources
            
    def _get_value(self, region, section, key):
        if key not in self._resource[region][section].keys():
            raise Exception('多语言资源文件中不存在key={}'.format(key))
        else:
            return self._resource[region][section][key]

    # ---------模块-----------------
    def req(self, key):
        return self._resource['REQ']
    
    def resp(self, key):
        """response返回值的多语言获取方法
        """
        if 'en-US' in self.accept_languages:
            return self._get_value('en-US', 'RESP', key)
        else:
            return self._get_value('zh-CN', 'RESP', key)
    
    def comm(self, key):
        """常用语的多语言获取方法
        """
        if 'en-US' in self.accept_languages:
            return self._get_value('en-US', 'COMMON', key)
        else:
            return self._get_value('zh-CN', 'COMMON', key)
    
    def mail(self, key):
        """邮件信息的多语言获取方法
        """
        if 'en-US' in self.accept_languages:
            return self._get_value('en-US', 'MAIL', key)
        else:
            return self._get_value('zh-CN', 'MAIL', key)
    # ---------模块-----------------
# lang = Language()
if __name__ == '__main__':
    lang = Language()
    
    



from setuptools import setup, find_packages            #这个包没有的可以pip一下

setup(
    name = "base_aios",      #这里是pip项目发布的名称
    version = "0.0.35",  #版本号，数值大的会优先被pip
    keywords = ("base", "aios", "package"),
    description = "base aios package",
    long_description="",
    license = "MIT Licence",

    url = "",     #项目相关文件地址，一般是github
    author = "",
    author_email="jian.lv@hotmail.com",

    packages = find_packages(),
    include_package_data = True,
    platforms = "any",
    install_requires=[],  #这个项目需要的第三方库
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ]
)